/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="ooxmlSaveOptionsData.ts">
 *   Copyright (c) 2023 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

import { AttributeInfo } from '../internal/attributeInfo';
import { ModelInterface } from './modelInterface';
import { SaveOptionsData } from './saveOptionsData';

export const importsMapOoxmlSaveOptionsData = {
    SaveOptionsData,
};

/**
 * Container class for docx/docm/dotx/dotm/flatopc save options.
 */
export abstract class OoxmlSaveOptionsData extends SaveOptionsData {
    /**
     * Attribute type map
     */
    public static attributeTypeMap: Array<AttributeInfo> = [
        {
            name: "compliance",
            baseName: "Compliance",
            type: "OoxmlSaveOptionsData.ComplianceEnum",
        },
        {
            name: "compressionLevel",
            baseName: "CompressionLevel",
            type: "OoxmlSaveOptionsData.CompressionLevelEnum",
        },
        {
            name: "password",
            baseName: "Password",
            type: "string",
        },
        {
            name: "prettyFormat",
            baseName: "PrettyFormat",
            type: "boolean",
        }
    ];

    /**
     * Returns attribute type map
     */
    public static getAttributeTypeMap() {
        return super.getAttributeTypeMap().concat(OoxmlSaveOptionsData.attributeTypeMap);
    }

    /**
     * Gets or sets the oOXML version for the output document.
     */
    public compliance: OoxmlSaveOptionsData.ComplianceEnum;

    /**
     * Gets or sets the compression level.
     */
    public compressionLevel: OoxmlSaveOptionsData.CompressionLevelEnum;

    /**
     * Gets or sets the password to encrypt document using ECMA376 Standard encryption algorithm.
     */
    public password: string;

    /**
     * Gets or sets a value indicating whether to use pretty formats output.
     */
    public prettyFormat: boolean;

    public constructor(init?: Partial< OoxmlSaveOptionsData >) {
        super(init);
        Object.assign(this, init);
    }

    public collectFilesContent(_resultFilesContent: Array<any>) {
    }
}

/**
 * Enums for OoxmlSaveOptionsData
 */
// tslint:disable:quotemark
// tslint:disable-next-line:no-namespace
export namespace OoxmlSaveOptionsData {
    export enum ComplianceEnum {
        Ecma376_2006 = 'Ecma376_2006' as any,
        Iso29500_2008_Transitional = 'Iso29500_2008_Transitional' as any,
        Iso29500_2008_Strict = 'Iso29500_2008_Strict' as any
    }

    export enum CompressionLevelEnum {
        Normal = 'Normal' as any,
        Maximum = 'Maximum' as any,
        Fast = 'Fast' as any,
        SuperFast = 'SuperFast' as any
    }
}
// tslint:enable:quotemark

